@@ -1,5 +1,5 @@
 # These functions are
-# Copyright (C) 1998-2013 T.W. Yee, University of Auckland.
+# Copyright (C) 1998-2014 T.W. Yee, University of Auckland.
 # All rights reserved.
 
 
@@ -235,7 +235,7 @@ vgam <- function(formula,
     "R"            = fit$R,
     "rank"         = fit$rank,
     "residuals"    = as.matrix(fit$residuals),
-    "res.ss"       = fit$res.ss,
+    "ResSS"       = fit$ResSS,
     "smart.prediction" = as.list(fit$smart.prediction),
     "terms"        = list(terms = fit$terms))
 
